==> sumo_1.24.0+dfsg1.orig.tar.xz: sumo-1_24_0/tests/netedit/elements/demands/personflow/inspect_selection/flow_attributes/probability/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2025 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

sys.path.append(os.path.join(os.environ.get("SUMO_HOME", "."), "tools"))
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart()

# go to demand mode
netedit.changeSupermode("demand")

# go to select mode
netedit.changeMode("select")

# select all using invert
netedit.selection("invert")

# go to inspect mode
netedit.changeMode("inspect")

# inspect person
netedit.leftClick(referencePosition, netedit.positions.elements.demands.person)

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacing, "dummyTerminate")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacing, "probability")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "dummy")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "12.5")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "26")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "0.3")

# Check undo
netedit.checkUndoRedo(referencePosition)

# save Netedit config
netedit.saveExistentShortcut("neteditConfig")

# save persons
# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.25.0+dfsg1.orig.tar.xz: sumo-1_25_0/tests/netedit/elements/demands/personflow/inspect_selection/flow_attributes/probability/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2025 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

sys.path.append(os.path.join(os.environ.get("SUMO_HOME", "."), "tools"))
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart()

# go to demand mode
netedit.changeSupermode("demand")

# go to select mode
netedit.changeMode("select")

# select all using invert
netedit.selection("invert")

# go to inspect mode
netedit.changeMode("inspect")

# inspect person
netedit.leftClick(referencePosition, netedit.positions.elements.demands.person)

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacing, "dummyTerminate")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacing, "probability")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "dummy")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "12.5")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "26")

# change flow value
netedit.modifyAttribute(netedit.attrs.personFlow.inspectSelection.spacingOption, "0.3")

# Check undo
netedit.checkUndoRedo(referencePosition)

# save Netedit config
netedit.saveExistentFile("neteditConfig")

# save persons
# quit netedit
netedit.quit(neteditProcess)
